@@ -1,25 +1,23 @@
 """MonfoDB support for Muffin Framework."""
+from __future__ import annotations
 
-import typing as t
+from typing import TYPE_CHECKING
 
-from muffin import Application
 from motor import motor_asyncio as motor
 from muffin.plugins import BasePlugin
 
-__version__ = "0.4.1"
-__project__ = "muffin-mongo"
-__author__ = "Kirill Klenov <horneds@gmail.com>"
-__license__ = "MIT"
+if TYPE_CHECKING:
+    from muffin import Application
 
 
 class Plugin(BasePlugin):
 
     """Manage Motor Client."""
 
-    name = 'mongo'
+    name = "mongo"
     defaults = {
-        'db_url': 'mongodb://localhost:27017',
-        'database': None,
+        "db_url": "mongodb://localhost:27017",
+        "database": None,
     }
 
     def __init__(self, *args, **kwargs):
@@ -32,7 +30,7 @@ class Plugin(BasePlugin):
         super().setup(app, **options)
         self.__client__ = motor.AsyncIOMotorClient(self.cfg.db_url)
 
-    def __getattr__(self, name) -> t.Any:
+    def __getattr__(self, name):
         """Proxy methods to the motor client."""
         proxy = self.__client__
         if self.cfg.database:
@@ -42,5 +40,5 @@ class Plugin(BasePlugin):
     @property
     def client(self):
         """Proxy the client."""
-        assert self.__client__, 'Please setup plugin with an application.'
+        assert self.__client__, "Please setup plugin with an application."
         return self.__client__
